#!/usr/bin/env python

"""
Reader and accessor classes for indexing.

Copyright (C) 2011 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

class TextFile:

    "A wrapper around text files."

    def __init__(self, f):
        self.f = f

    def seek(self, pos):
        self.f.seek(pos)

    def get_records(self):
        return self.f.xreadlines()

class DelimitedRecord:

    "An accessor using a delimiter to split a record."

    def __init__(self, keys=None, delimiter=None, numeric=0):

        """
        Initialise the accessor using a sequence of 'keys' indicating the
        columns in each record that provide the values in the eventual compound
        key provided by each record, along with a 'delimiter' indicating how
        such columns are identified. If 'numeric' is set to a true value, keys
        will be interpreted as numbers.
        """

        self.keys = keys or [0]
        self.delimiter = delimiter
        self.convert = numeric and self.convert_numeric or (lambda x: x)

    def convert_numeric(self, term):
        return map(int, term)

    def get_key(self, record):
        values = record.split(self.delimiter)
        return self.convert([values[key] for key in self.keys])

# vim: tabstop=4 expandtab shiftwidth=4
